@@ -119,7 +119,7 @@ class ProfileAddon(caches.CachedAddon):
     non_profile_dirs = frozenset(["desc", "updates"])
 
     # cache registry
-    cache = caches.CacheData(type="profiles", file="profiles.pickle", version=2)
+    cache = caches.CacheData(type="profiles", file="profiles.pickle.zst", version=3)
 
     @classmethod
     def mangle_argparser(cls, parser):
@@ -359,7 +359,7 @@ class ProfileAddon(caches.CachedAddon):
                         # stable cache is usable for unstable, but not vice versa.
                         # unstable insoluble is usable for stable, but not vice versa
                         vfilter = domain.generate_filter(
-                            self.target_repo.pkg_masks | masks, unmasks
+                            self.target_repo.pkg_masks | repo.pkg_masks | masks, unmasks
                         )
                         self.profile_filters.setdefault(stable_key, []).append(
                             ProfileData(
